﻿// Copyright 2013-2014 Andrew C. Dvorak
//
// This file is part of BDHero.
//
// BDHero is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// BDHero is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with BDHero.  If not, see <http://www.gnu.org/licenses/>.

// ReSharper disable InconsistentNaming
namespace NativeAPI.Win.User
{
    /// <summary>
    ///     Commands for <see cref="WindowAPI.ShowWindow"/> and <see cref="WindowAPI.ShowWindowAsync"/>.
    /// </summary>
    public enum ShowWindowCommand
    {
        /// <summary>
        ///     Minimizes a window, even if the thread that owns the window is not responding.
        ///     This flag should only be used when minimizing windows from a different thread.
        /// </summary>
        SW_FORCEMINIMIZE = 11,

        /// <summary>
        ///     Hides the window and activates another window.
        /// </summary>
        SW_HIDE = 0,

        /// <summary>
        ///     Maximizes the specified window.
        /// </summary>
        SW_MAXIMIZE = 3,

        /// <summary>
        ///     Minimizes the specified window and activates the next top-level window in the Z order.
        /// </summary>
        SW_MINIMIZE = 6,

        /// <summary>
        ///     Activates and displays the window. If the window is minimized or maximized, the system restores it
        ///     to its original size and position. An application should specify this flag when restoring a minimized window.
        /// </summary>
        SW_RESTORE = 9,

        /// <summary>
        ///     Activates the window and displays it in its current size and position.
        /// </summary>
        SW_SHOW = 5,

        /// <summary>
        ///     Sets the show state based on the value specified in the <c>STARTUPINFO</c> structure passed to the
        ///     <c>CreateProcess</c> function by the program that started the application.
        /// </summary>
        SW_SHOWDEFAULT = 10,

        /// <summary>
        ///     Activates the window and displays it as a maximized window.
        /// </summary>
        SW_SHOWMAXIMIZED = 3,

        /// <summary>
        ///     Activates the window and displays it as a minimized window.
        /// </summary>
        SW_SHOWMINIMIZED = 2,

        /// <summary>
        ///     Displays the window as a minimized window. This value is similar to <see cref="SW_SHOWMINIMIZED"/>,
        ///     except the window is not activated.
        /// </summary>
        SW_SHOWMINNOACTIVE = 7,

        /// <summary>
        ///     Displays the window in its current size and position. This value is similar to <see cref="SW_SHOW"/>,
        ///     except that the window is not activated.
        /// </summary>
        SW_SHOWNA = 8,

        /// <summary>
        ///     Displays a window in its most recent size and position. This value is similar to <see cref="SW_SHOWNORMAL"/>,
        ///     except that the window is not activated.
        /// </summary>
        SW_SHOWNOACTIVATE = 4,

        /// <summary>
        ///     Activates and displays a window. If the window is minimized or maximized, the system restores
        ///     it to its original size and position. An application should specify this flag when displaying the window for the first time.
        /// </summary>
        SW_SHOWNORMAL = 1
    }
}
